@@ -115,15 +115,6 @@ class CrossFeaturePredictBatchOp(BatchOperator):
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -190,6 +181,9 @@ class CsvSourceBatchOp(BatchOperator):
     def setFieldDelimiter(self, val):
         return self._add_param('fieldDelimiter', val)
 
+    def setHandleInvalidMethod(self, val):
+        return self._add_param('handleInvalidMethod', val)
+
     def setIgnoreFirstLine(self, val):
         return self._add_param('ignoreFirstLine', val)
 
@@ -460,15 +454,6 @@ class DecisionTreePredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -503,15 +488,6 @@ class DecisionTreeRegPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -727,6 +703,59 @@ class DeepARTrainBatchOp(BatchOperator):
         return self._add_param('window', val)
 
 
+class DeepWalkBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.graph.DeepWalkBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(DeepWalkBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSourceCol(self, val):
+        return self._add_param('sourceCol', val)
+
+    def setTargetCol(self, val):
+        return self._add_param('targetCol', val)
+
+    def setWalkLength(self, val):
+        return self._add_param('walkLength', val)
+
+    def setWalkNum(self, val):
+        return self._add_param('walkNum', val)
+
+    def setAlpha(self, val):
+        return self._add_param('alpha', val)
+
+    def setBatchSize(self, val):
+        return self._add_param('batchSize', val)
+
+    def setIsToUndigraph(self, val):
+        return self._add_param('isToUndigraph', val)
+
+    def setMinCount(self, val):
+        return self._add_param('minCount', val)
+
+    def setNegative(self, val):
+        return self._add_param('negative', val)
+
+    def setNumIter(self, val):
+        return self._add_param('numIter', val)
+
+    def setRandomWindow(self, val):
+        return self._add_param('randomWindow', val)
+
+    def setVectorSize(self, val):
+        return self._add_param('vectorSize', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+    def setWindow(self, val):
+        return self._add_param('window', val)
+
+
 class DistinctBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.sql.DistinctBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -751,15 +780,6 @@ class DocCountVectorizerPredictBatchOp(BatchOperator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -812,15 +832,6 @@ class DocHashCountVectorizerPredictBatchOp(BatchOperator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -948,15 +959,6 @@ class EqualWidthDiscretizerPredictBatchOp(BatchOperator):
     def setHandleInvalid(self, val):
         return self._add_param('handleInvalid', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1149,11 +1151,11 @@ class ExtractMfccFeatureBatchOp(BatchOperator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
-    def setHopSecond(self, val):
-        return self._add_param('hopSecond', val)
+    def setHopTime(self, val):
+        return self._add_param('hopTime', val)
 
-    def setNMfcc(self, val):
-        return self._add_param('nMfcc', val)
+    def setNumMfcc(self, val):
+        return self._add_param('numMfcc', val)
 
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
@@ -1164,8 +1166,8 @@ class ExtractMfccFeatureBatchOp(BatchOperator):
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-    def setWindowSecond(self, val):
-        return self._add_param('windowSecond', val)
+    def setWindowTime(self, val):
+        return self._add_param('windowTime', val)
 
 
 class FeatureHasherBatchOp(BatchOperator):
@@ -1295,15 +1297,6 @@ class FmClassifierPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1316,59 +1309,3 @@ class FmClassifierPredictBatchOp(BatchOperator):
     def setVectorCol(self, val):
         return self._add_param('vectorCol', val)
 
-
-class FmClassifierTrainBatchOp(BatchOperator, WithModelInfoBatchOp, WithTrainInfo):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.classification.FmClassifierTrainBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(FmClassifierTrainBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setEpsilon(self, val):
-        return self._add_param('epsilon', val)
-
-    def setFeatureCols(self, val):
-        return self._add_param('featureCols', val)
-
-    def setInitStdev(self, val):
-        return self._add_param('initStdev', val)
-
-    def setLambda0(self, val):
-        return self._add_param('lambda0', val)
-
-    def setLambda1(self, val):
-        return self._add_param('lambda1', val)
-
-    def setLambda2(self, val):
-        return self._add_param('lambda2', val)
-
-    def setLearnRate(self, val):
-        return self._add_param('learnRate', val)
-
-    def setMinibatchSize(self, val):
-        return self._add_param('minibatchSize', val)
-
-    def setNumEpochs(self, val):
-        return self._add_param('numEpochs', val)
-
-    def setNumFactor(self, val):
-        return self._add_param('numFactor', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setWeightCol(self, val):
-        return self._add_param('weightCol', val)
-
-    def setWithIntercept(self, val):
-        return self._add_param('withIntercept', val)
-
-    def setWithLinearItem(self, val):
-        return self._add_param('withLinearItem', val)
-
