@@ -7,6 +7,62 @@ from ..lazy.with_model_info_batch_op import WithModelInfoBatchOp
 from ..lazy.with_train_info import WithTrainInfo
 
 
+class FmClassifierTrainBatchOp(BatchOperator, WithModelInfoBatchOp, WithTrainInfo):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.classification.FmClassifierTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(FmClassifierTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setBatchSize(self, val):
+        return self._add_param('batchSize', val)
+
+    def setEpsilon(self, val):
+        return self._add_param('epsilon', val)
+
+    def setFeatureCols(self, val):
+        return self._add_param('featureCols', val)
+
+    def setInitStdev(self, val):
+        return self._add_param('initStdev', val)
+
+    def setLambda0(self, val):
+        return self._add_param('lambda0', val)
+
+    def setLambda1(self, val):
+        return self._add_param('lambda1', val)
+
+    def setLambda2(self, val):
+        return self._add_param('lambda2', val)
+
+    def setLearnRate(self, val):
+        return self._add_param('learnRate', val)
+
+    def setNumEpochs(self, val):
+        return self._add_param('numEpochs', val)
+
+    def setNumFactor(self, val):
+        return self._add_param('numFactor', val)
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+    def setWithIntercept(self, val):
+        return self._add_param('withIntercept', val)
+
+    def setWithLinearItem(self, val):
+        return self._add_param('withLinearItem', val)
+
+
 class FmItemsPerUserRecommBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.recommendation.FmItemsPerUserRecommBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -32,15 +88,6 @@ class FmItemsPerUserRecommBatchOp(BatchOperator):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -61,15 +108,6 @@ class FmPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -102,15 +140,6 @@ class FmRateRecommBatchOp(BatchOperator):
     def setUserCol(self, val):
         return self._add_param('userCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -260,15 +289,6 @@ class FmRegressorPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -295,6 +315,9 @@ class FmRegressorTrainBatchOp(BatchOperator, WithModelInfoBatchOp, WithTrainInfo
     def setLabelCol(self, val):
         return self._add_param('labelCol', val)
 
+    def setBatchSize(self, val):
+        return self._add_param('batchSize', val)
+
     def setEpsilon(self, val):
         return self._add_param('epsilon', val)
 
@@ -316,9 +339,6 @@ class FmRegressorTrainBatchOp(BatchOperator, WithModelInfoBatchOp, WithTrainInfo
     def setLearnRate(self, val):
         return self._add_param('learnRate', val)
 
-    def setMinibatchSize(self, val):
-        return self._add_param('minibatchSize', val)
-
     def setNumEpochs(self, val):
         return self._add_param('numEpochs', val)
 
@@ -363,15 +383,6 @@ class FmUsersPerItemRecommBatchOp(BatchOperator):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -455,15 +466,6 @@ class GbdtPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -501,15 +503,6 @@ class GbdtRegPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -542,8 +535,8 @@ class GbdtRegTrainBatchOp(BatchOperator, WithModelInfoBatchOp):
     def setCategoricalCols(self, val):
         return self._add_param('categoricalCols', val)
 
-    def setCriteriaType(self, val):
-        return self._add_param('criteriaType', val)
+    def setCriteria(self, val):
+        return self._add_param('criteria', val)
 
     def setFeatureImportanceType(self, val):
         return self._add_param('featureImportanceType', val)
@@ -634,8 +627,8 @@ class GbdtTrainBatchOp(BatchOperator, WithModelInfoBatchOp):
     def setCategoricalCols(self, val):
         return self._add_param('categoricalCols', val)
 
-    def setCriteriaType(self, val):
-        return self._add_param('criteriaType', val)
+    def setCriteria(self, val):
+        return self._add_param('criteria', val)
 
     def setFeatureImportanceType(self, val):
         return self._add_param('featureImportanceType', val)
@@ -717,15 +710,6 @@ class GeoKMeansPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -848,15 +832,6 @@ class GlmPredictBatchOp(BatchOperator):
     def setLinkPredResultCol(self, val):
         return self._add_param('linkPredResultCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -938,15 +913,6 @@ class GmmPredictBatchOp(BatchOperator):
     def setVectorCol(self, val):
         return self._add_param('vectorCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1230,15 +1196,6 @@ class HugeLookupBatchOp(BatchOperator):
     def setMapValueCols(self, val):
         return self._add_param('mapValueCols', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setModelStreamUpdateMethod(self, val):
         return self._add_param('modelStreamUpdateMethod', val)
 
@@ -1525,15 +1482,6 @@ class Id3PredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1612,15 +1560,6 @@ class ImputerPredictBatchOp(BatchOperator):
         super(ImputerPredictBatchOp, self).__init__(*args, **kwargs)
         pass
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1664,15 +1603,6 @@ class IndexToStringPredictBatchOp(BatchOperator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1683,6 +1613,44 @@ class IndexToStringPredictBatchOp(BatchOperator):
         return self._add_param('reservedCols', val)
 
 
+class InternalCsvSourceBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.common.io.csv.InternalCsvSourceBatchOp'
+    OP_TYPE = 'SOURCE'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(InternalCsvSourceBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setFilePath(self, val):
+        return self._add_param('filePath', val)
+
+    def setSchemaStr(self, val):
+        return self._add_param('schemaStr', val)
+
+    def setFieldDelimiter(self, val):
+        return self._add_param('fieldDelimiter', val)
+
+    def setHandleInvalidMethod(self, val):
+        return self._add_param('handleInvalidMethod', val)
+
+    def setIgnoreFirstLine(self, val):
+        return self._add_param('ignoreFirstLine', val)
+
+    def setLenient(self, val):
+        return self._add_param('lenient', val)
+
+    def setQuoteChar(self, val):
+        return self._add_param('quoteChar', val)
+
+    def setRowDelimiter(self, val):
+        return self._add_param('rowDelimiter', val)
+
+    def setSkipBlankLine(self, val):
+        return self._add_param('skipBlankLine', val)
+
+
 class IntersectAllBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.sql.IntersectAllBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -1704,105 +1672,3 @@ class IntersectBatchOp(BatchOperator):
         super(IntersectBatchOp, self).__init__(*args, **kwargs)
         pass
 
-
-class IsolationForestsPredictBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.outlier.IsolationForestsPredictBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(IsolationForestsPredictBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class IsolationForestsTrainBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.outlier.IsolationForestsTrainBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(IsolationForestsTrainBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setFeatureCols(self, val):
-        return self._add_param('featureCols', val)
-
-    def setMaxDepth(self, val):
-        return self._add_param('maxDepth', val)
-
-    def setMaxLeaves(self, val):
-        return self._add_param('maxLeaves', val)
-
-    def setMinSampleRatioPerChild(self, val):
-        return self._add_param('minSampleRatioPerChild', val)
-
-    def setMinSamplesPerLeaf(self, val):
-        return self._add_param('minSamplesPerLeaf', val)
-
-    def setNumTrees(self, val):
-        return self._add_param('numTrees', val)
-
-    def setSeed(self, val):
-        return self._add_param('seed', val)
-
-    def setSubsamplingRatio(self, val):
-        return self._add_param('subsamplingRatio', val)
-
-
-class IsolationForestsBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.outlier.IsolationForestsTrainBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(IsolationForestsBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setFeatureCols(self, val):
-        return self._add_param('featureCols', val)
-
-    def setMaxDepth(self, val):
-        return self._add_param('maxDepth', val)
-
-    def setMaxLeaves(self, val):
-        return self._add_param('maxLeaves', val)
-
-    def setMinSampleRatioPerChild(self, val):
-        return self._add_param('minSampleRatioPerChild', val)
-
-    def setMinSamplesPerLeaf(self, val):
-        return self._add_param('minSamplesPerLeaf', val)
-
-    def setNumTrees(self, val):
-        return self._add_param('numTrees', val)
-
-    def setSeed(self, val):
-        return self._add_param('seed', val)
-
-    def setSubsamplingRatio(self, val):
-        return self._add_param('subsamplingRatio', val)
-
