@@ -7,6 +7,99 @@ from ..lazy.with_model_info_batch_op import WithModelInfoBatchOp
 from ..lazy.with_train_info import WithTrainInfo
 
 
+class IsolationForestsPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.outlier.IsolationForestsPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(IsolationForestsPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class IsolationForestsTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.outlier.IsolationForestsTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(IsolationForestsTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setFeatureCols(self, val):
+        return self._add_param('featureCols', val)
+
+    def setMaxDepth(self, val):
+        return self._add_param('maxDepth', val)
+
+    def setMaxLeaves(self, val):
+        return self._add_param('maxLeaves', val)
+
+    def setMinSampleRatioPerChild(self, val):
+        return self._add_param('minSampleRatioPerChild', val)
+
+    def setMinSamplesPerLeaf(self, val):
+        return self._add_param('minSamplesPerLeaf', val)
+
+    def setNumTrees(self, val):
+        return self._add_param('numTrees', val)
+
+    def setSeed(self, val):
+        return self._add_param('seed', val)
+
+    def setSubsamplingRatio(self, val):
+        return self._add_param('subsamplingRatio', val)
+
+
+class IsolationForestsBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.outlier.IsolationForestsTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(IsolationForestsBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setFeatureCols(self, val):
+        return self._add_param('featureCols', val)
+
+    def setMaxDepth(self, val):
+        return self._add_param('maxDepth', val)
+
+    def setMaxLeaves(self, val):
+        return self._add_param('maxLeaves', val)
+
+    def setMinSampleRatioPerChild(self, val):
+        return self._add_param('minSampleRatioPerChild', val)
+
+    def setMinSamplesPerLeaf(self, val):
+        return self._add_param('minSamplesPerLeaf', val)
+
+    def setNumTrees(self, val):
+        return self._add_param('numTrees', val)
+
+    def setSeed(self, val):
+        return self._add_param('seed', val)
+
+    def setSubsamplingRatio(self, val):
+        return self._add_param('subsamplingRatio', val)
+
+
 class IsotonicRegPredictBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.regression.IsotonicRegPredictBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -20,15 +113,6 @@ class IsotonicRegPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -87,15 +171,6 @@ class ItemCfItemsPerUserRecommBatchOp(BatchOperator):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -133,15 +208,6 @@ class ItemCfRateRecommBatchOp(BatchOperator):
     def setUserCol(self, val):
         return self._add_param('userCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -171,15 +237,6 @@ class ItemCfSimilarItemsRecommBatchOp(BatchOperator):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -241,15 +298,6 @@ class ItemCfUsersPerItemRecommBatchOp(BatchOperator):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -466,15 +514,6 @@ class KMeansPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -568,8 +607,8 @@ class KerasSequentialClassifierTrainBatchOp(BatchOperator):
     def setBatchSize(self, val):
         return self._add_param('batchSize', val)
 
-    def setBesteMetric(self, val):
-        return self._add_param('besteMetric', val)
+    def setBestMetric(self, val):
+        return self._add_param('bestMetric', val)
 
     def setCheckpointFilePath(self, val):
         return self._add_param('checkpointFilePath', val)
@@ -653,8 +692,8 @@ class KerasSequentialRegressorTrainBatchOp(BatchOperator):
     def setBatchSize(self, val):
         return self._add_param('batchSize', val)
 
-    def setBesteMetric(self, val):
-        return self._add_param('besteMetric', val)
+    def setBestMetric(self, val):
+        return self._add_param('bestMetric', val)
 
     def setCheckpointFilePath(self, val):
         return self._add_param('checkpointFilePath', val)
@@ -747,15 +786,6 @@ class KnnPredictBatchOp(BatchOperator):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1087,15 +1117,6 @@ class LassoRegPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1174,15 +1195,6 @@ class LdaPredictBatchOp(BatchOperator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1435,15 +1447,6 @@ class LinearRegPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1497,49 +1500,3 @@ class LinearRegTrainBatchOp(BatchOperator, WithModelInfoBatchOp, WithTrainInfo):
     def setWithIntercept(self, val):
         return self._add_param('withIntercept', val)
 
-
-class LinearSvmModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.classification.LinearSvmModelInfoBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LinearSvmModelInfoBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-
-class LinearSvmPredictBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.classification.LinearSvmPredictBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LinearSvmPredictBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
