@@ -7,6 +7,154 @@ from ..lazy.with_model_info_batch_op import WithModelInfoBatchOp
 from ..lazy.with_train_info import WithTrainInfo
 
 
+class ProphetBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.timeseries.ProphetBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ProphetBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setValueCol(self, val):
+        return self._add_param('valueCol', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictNum(self, val):
+        return self._add_param('predictNum', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setPythonEnv(self, val):
+        return self._add_param('pythonEnv', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setStanInit(self, val):
+        return self._add_param('stanInit', val)
+
+    def setUncertaintySamples(self, val):
+        return self._add_param('uncertaintySamples', val)
+
+
+class ProphetPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.timeseries.ProphetPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ProphetPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setValueCol(self, val):
+        return self._add_param('valueCol', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictNum(self, val):
+        return self._add_param('predictNum', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setPythonEnv(self, val):
+        return self._add_param('pythonEnv', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class ProphetTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.timeseries.ProphetTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ProphetTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setTimeCol(self, val):
+        return self._add_param('timeCol', val)
+
+    def setValueCol(self, val):
+        return self._add_param('valueCol', val)
+
+    def setPythonEnv(self, val):
+        return self._add_param('pythonEnv', val)
+
+
+class PyBinaryScalarFunctionBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.executor.udf.python.PyBinaryScalarFunctionBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(PyBinaryScalarFunctionBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setClassObject(self, val):
+        return self._add_param('classObject', val)
+
+    def setClassObjectType(self, val):
+        return self._add_param('classObjectType', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setResultType(self, val):
+        return self._add_param('resultType', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class PyBinaryTableFunctionBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.executor.udf.python.PyBinaryTableFunctionBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(PyBinaryTableFunctionBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setClassObject(self, val):
+        return self._add_param('classObject', val)
+
+    def setClassObjectType(self, val):
+        return self._add_param('classObjectType', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+    def setResultTypes(self, val):
+        return self._add_param('resultTypes', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class QuantileDiscretizerModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
     CLS_NAME = 'com.alibaba.alink.operator.batch.feature.QuantileDiscretizerModelInfoBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -40,15 +188,6 @@ class QuantileDiscretizerPredictBatchOp(BatchOperator):
     def setHandleInvalid(self, val):
         return self._add_param('handleInvalid', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -106,15 +245,6 @@ class RandomForestPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -149,15 +279,6 @@ class RandomForestRegPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -404,18 +525,18 @@ class ReadAudioToTensorBatchOp(BatchOperator):
     def setSampleRate(self, val):
         return self._add_param('sampleRate', val)
 
-    def setDurationTime(self, val):
-        return self._add_param('durationTime', val)
+    def setDuration(self, val):
+        return self._add_param('duration', val)
 
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
+    def setOffset(self, val):
+        return self._add_param('offset', val)
+
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-    def setStartTime(self, val):
-        return self._add_param('startTime', val)
-
 
 class ReadImageToTensorBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.image.ReadImageToTensorBatchOp'
@@ -457,6 +578,61 @@ class RebalanceBatchOp(BatchOperator):
         pass
 
 
+class RecommendationRankingBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.recommendation.RecommendationRankingBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RecommendationRankingBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setMTableCol(self, val):
+        return self._add_param('mTableCol', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setRankingCol(self, val):
+        return self._add_param('rankingCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setTopN(self, val):
+        return self._add_param('topN', val)
+
+
+class RedisSinkBatchOp(BaseSinkBatchOp):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.sink.RedisSinkBatchOp'
+    OP_TYPE = 'SINK'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RedisSinkBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPluginVersion(self, val):
+        return self._add_param('pluginVersion', val)
+
+    def setRedisIP(self, val):
+        return self._add_param('redisIP', val)
+
+    def setKeyCols(self, val):
+        return self._add_param('keyCols', val)
+
+    def setRedisPassword(self, val):
+        return self._add_param('redisPassword', val)
+
+    def setRedisPort(self, val):
+        return self._add_param('redisPort', val)
+
+    def setValueCols(self, val):
+        return self._add_param('valueCols', val)
+
+
 class RegexTokenizerBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.nlp.RegexTokenizerBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -516,15 +692,6 @@ class RidgeRegPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -751,15 +918,6 @@ class SoftmaxPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -892,15 +1050,6 @@ class StandardScalerPredictBatchOp(BatchOperator):
         super(StandardScalerPredictBatchOp, self).__init__(*args, **kwargs)
         pass
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1080,15 +1229,6 @@ class StringIndexerPredictBatchOp(BatchOperator):
     def setHandleInvalid(self, val):
         return self._add_param('handleInvalid', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1121,230 +1261,3 @@ class StringIndexerTrainBatchOp(BatchOperator):
     def setStringOrderType(self, val):
         return self._add_param('stringOrderType', val)
 
-
-class StringNearestNeighborPredictBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.similarity.StringNearestNeighborPredictBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(StringNearestNeighborPredictBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setRadius(self, val):
-        return self._add_param('radius', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setTopN(self, val):
-        return self._add_param('topN', val)
-
-
-class StringNearestNeighborTrainBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.similarity.StringNearestNeighborTrainBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(StringNearestNeighborTrainBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setIdCol(self, val):
-        return self._add_param('idCol', val)
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setTrainType(self, val):
-        return self._add_param('trainType', val)
-
-    def setLambda(self, val):
-        return self._add_param('lambda', val)
-
-    def setMetric(self, val):
-        return self._add_param('metric', val)
-
-    def setWindowSize(self, val):
-        return self._add_param('windowSize', val)
-
-
-class StringSimilarityPairwiseBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.similarity.StringSimilarityPairwiseBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(StringSimilarityPairwiseBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setLambda(self, val):
-        return self._add_param('lambda', val)
-
-    def setMetric(self, val):
-        return self._add_param('metric', val)
-
-    def setNumBucket(self, val):
-        return self._add_param('numBucket', val)
-
-    def setNumHashTables(self, val):
-        return self._add_param('numHashTables', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setSeed(self, val):
-        return self._add_param('seed', val)
-
-    def setWindowSize(self, val):
-        return self._add_param('windowSize', val)
-
-
-class SummarizerBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.statistics.SummarizerBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(SummarizerBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-
-class SwingRecommBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.recommendation.SwingRecommBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(SwingRecommBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setItemCol(self, val):
-        return self._add_param('itemCol', val)
-
-    def setRecommCol(self, val):
-        return self._add_param('recommCol', val)
-
-    def setInitRecommCol(self, val):
-        return self._add_param('initRecommCol', val)
-
-    def setK(self, val):
-        return self._add_param('k', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class SwingTrainBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.recommendation.SwingTrainBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(SwingTrainBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setItemCol(self, val):
-        return self._add_param('itemCol', val)
-
-    def setUserCol(self, val):
-        return self._add_param('userCol', val)
-
-    def setAlpha(self, val):
-        return self._add_param('alpha', val)
-
-    def setMaxItemNumber(self, val):
-        return self._add_param('maxItemNumber', val)
-
-    def setMaxUserItems(self, val):
-        return self._add_param('maxUserItems', val)
-
-    def setMinUserItems(self, val):
-        return self._add_param('minUserItems', val)
-
-    def setRateCol(self, val):
-        return self._add_param('rateCol', val)
-
-    def setResultNormalize(self, val):
-        return self._add_param('resultNormalize', val)
-
-    def setUserAlpha(self, val):
-        return self._add_param('userAlpha', val)
-
-    def setUserBeta(self, val):
-        return self._add_param('userBeta', val)
-
-
-class TF2TableModelTrainBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.tensorflow.TF2TableModelTrainBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(TF2TableModelTrainBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setMainScriptFile(self, val):
-        return self._add_param('mainScriptFile', val)
-
-    def setUserFiles(self, val):
-        return self._add_param('userFiles', val)
-
-    def setIntraOpParallelism(self, val):
-        return self._add_param('intraOpParallelism', val)
-
-    def setNumPSs(self, val):
-        return self._add_param('numPSs', val)
-
-    def setNumWorkers(self, val):
-        return self._add_param('numWorkers', val)
-
-    def setPythonEnv(self, val):
-        return self._add_param('pythonEnv', val)
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setUserParams(self, val):
-        return self._add_param('userParams', val)
-
