@@ -7,6 +7,224 @@ from ..lazy.with_model_info_batch_op import WithModelInfoBatchOp
 from ..lazy.with_train_info import WithTrainInfo
 
 
+class StringNearestNeighborPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.similarity.StringNearestNeighborPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(StringNearestNeighborPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setRadius(self, val):
+        return self._add_param('radius', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setTopN(self, val):
+        return self._add_param('topN', val)
+
+
+class StringNearestNeighborTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.similarity.StringNearestNeighborTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(StringNearestNeighborTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setIdCol(self, val):
+        return self._add_param('idCol', val)
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setTrainType(self, val):
+        return self._add_param('trainType', val)
+
+    def setLambda(self, val):
+        return self._add_param('lambda', val)
+
+    def setMetric(self, val):
+        return self._add_param('metric', val)
+
+    def setWindowSize(self, val):
+        return self._add_param('windowSize', val)
+
+
+class StringSimilarityPairwiseBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.similarity.StringSimilarityPairwiseBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(StringSimilarityPairwiseBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setLambda(self, val):
+        return self._add_param('lambda', val)
+
+    def setMetric(self, val):
+        return self._add_param('metric', val)
+
+    def setNumBucket(self, val):
+        return self._add_param('numBucket', val)
+
+    def setNumHashTables(self, val):
+        return self._add_param('numHashTables', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSeed(self, val):
+        return self._add_param('seed', val)
+
+    def setWindowSize(self, val):
+        return self._add_param('windowSize', val)
+
+
+class SummarizerBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.statistics.SummarizerBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(SummarizerBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+
+class SwingRecommBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.recommendation.SwingRecommBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(SwingRecommBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setItemCol(self, val):
+        return self._add_param('itemCol', val)
+
+    def setRecommCol(self, val):
+        return self._add_param('recommCol', val)
+
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
+    def setK(self, val):
+        return self._add_param('k', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class SwingTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.recommendation.SwingTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(SwingTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setItemCol(self, val):
+        return self._add_param('itemCol', val)
+
+    def setUserCol(self, val):
+        return self._add_param('userCol', val)
+
+    def setAlpha(self, val):
+        return self._add_param('alpha', val)
+
+    def setMaxItemNumber(self, val):
+        return self._add_param('maxItemNumber', val)
+
+    def setMaxUserItems(self, val):
+        return self._add_param('maxUserItems', val)
+
+    def setMinUserItems(self, val):
+        return self._add_param('minUserItems', val)
+
+    def setRateCol(self, val):
+        return self._add_param('rateCol', val)
+
+    def setResultNormalize(self, val):
+        return self._add_param('resultNormalize', val)
+
+    def setUserAlpha(self, val):
+        return self._add_param('userAlpha', val)
+
+    def setUserBeta(self, val):
+        return self._add_param('userBeta', val)
+
+
+class TF2TableModelTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.tensorflow.TF2TableModelTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(TF2TableModelTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setMainScriptFile(self, val):
+        return self._add_param('mainScriptFile', val)
+
+    def setUserFiles(self, val):
+        return self._add_param('userFiles', val)
+
+    def setIntraOpParallelism(self, val):
+        return self._add_param('intraOpParallelism', val)
+
+    def setNumPSs(self, val):
+        return self._add_param('numPSs', val)
+
+    def setNumWorkers(self, val):
+        return self._add_param('numWorkers', val)
+
+    def setPythonEnv(self, val):
+        return self._add_param('pythonEnv', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setUserParams(self, val):
+        return self._add_param('userParams', val)
+
+
 class TFSavedModelPredictBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.tensorflow.TFSavedModelPredictBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -442,6 +660,93 @@ class TfidfBatchOp(BatchOperator):
         return self._add_param('wordCol', val)
 
 
+class ToMTableBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.ToMTableBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ToMTableBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setHandleInvalidMethod(self, val):
+        return self._add_param('handleInvalidMethod', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class ToTensorBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.ToTensorBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ToTensorBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setHandleInvalidMethod(self, val):
+        return self._add_param('handleInvalidMethod', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setTensorDataType(self, val):
+        return self._add_param('tensorDataType', val)
+
+    def setTensorShape(self, val):
+        return self._add_param('tensorShape', val)
+
+
+class ToVectorBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.ToVectorBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ToVectorBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setHandleInvalidMethod(self, val):
+        return self._add_param('handleInvalidMethod', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorType(self, val):
+        return self._add_param('vectorType', val)
+
+
 class TokenizerBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.nlp.TokenizerBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -478,15 +783,6 @@ class TreeModelEncoderBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -749,15 +1045,6 @@ class UserCfItemsPerUserRecommBatchOp(BatchOperator):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -795,15 +1082,6 @@ class UserCfRateRecommBatchOp(BatchOperator):
     def setUserCol(self, val):
         return self._add_param('userCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -833,15 +1111,6 @@ class UserCfSimilarUsersRecommBatchOp(BatchOperator):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -903,15 +1172,6 @@ class UserCfUsersPerItemRecommBatchOp(BatchOperator):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1012,6 +1272,32 @@ class VectorAssemblerBatchOp(BatchOperator):
         return self._add_param('reservedCols', val)
 
 
+class VectorBiFunctionBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorBiFunctionBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorBiFunctionBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setBiFuncName(self, val):
+        return self._add_param('biFuncName', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class VectorChiSqSelectorBatchOp(BatchOperator, WithModelInfoBatchOp):
     CLS_NAME = 'com.alibaba.alink.operator.batch.feature.VectorChiSqSelectorBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -1080,217 +1366,3 @@ class VectorCorrelationBatchOp(BatchOperator):
     def setMethod(self, val):
         return self._add_param('method', val)
 
-
-class VectorElementwiseProductBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorElementwiseProductBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorElementwiseProductBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setScalingVector(self, val):
-        return self._add_param('scalingVector', val)
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorImputerModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorImputerModelInfoBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorImputerModelInfoBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-
-class VectorImputerPredictBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorImputerPredictBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorImputerPredictBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-
-class VectorImputerTrainBatchOp(BatchOperator, WithModelInfoBatchOp):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorImputerTrainBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorImputerTrainBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setFillValue(self, val):
-        return self._add_param('fillValue', val)
-
-    def setStrategy(self, val):
-        return self._add_param('strategy', val)
-
-
-class VectorInteractionBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorInteractionBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorInteractionBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorMaxAbsScalerModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorMaxAbsScalerModelInfoBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorMaxAbsScalerModelInfoBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-
-class VectorMaxAbsScalerPredictBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorMaxAbsScalerPredictBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorMaxAbsScalerPredictBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-
-class VectorMaxAbsScalerTrainBatchOp(BatchOperator, WithModelInfoBatchOp):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorMaxAbsScalerTrainBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorMaxAbsScalerTrainBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-
-class VectorMinMaxScalerModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorMinMaxScalerModelInfoBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorMinMaxScalerModelInfoBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-
-class VectorMinMaxScalerPredictBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorMinMaxScalerPredictBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorMinMaxScalerPredictBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-
-class VectorMinMaxScalerTrainBatchOp(BatchOperator, WithModelInfoBatchOp):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorMinMaxScalerTrainBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorMinMaxScalerTrainBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setMax(self, val):
-        return self._add_param('max', val)
-
-    def setMin(self, val):
-        return self._add_param('min', val)
-
