@@ -6,6 +6,7 @@ from .common import EvalMultiClassBatchOp as _EvalMultiClassBatchOp
 from .common import EvalRegressionBatchOp as _EvalRegressionBatchOp
 from .common import EvalMultiLabelBatchOp as _EvalMultiLabelBatchOp
 from .common import EvalRankingBatchOp as _EvalRankingBatchOp
+from .common import EvalTimeSeriesBatchOp as _EvalTimeSeriesBatchOp
 from .common import SummarizerBatchOp as _SummarizerBatchOp
 from .common import VectorChiSquareTestBatchOp as _VectorChiSquareTestBatchOp
 from .common import VectorCorrelationBatchOp as _VectorCorrelationBatchOp
@@ -58,6 +59,10 @@ class EvalRankingBatchOp(_EvalRankingBatchOp, EvaluationMetricsCollector):
     pass
 
 
+class EvalTimeSeriesBatchOp(_EvalTimeSeriesBatchOp, EvaluationMetricsCollector):
+    pass
+
+
 class ChiSquareTestBatchOp(_ChiSquareTestBatchOp):
     @auto_convert_java_type
     def collectChiSquareTest(self):
