@@ -8,6 +8,71 @@ from ..lazy.has_lazy_print_train_info import HasLazyPrintTrainInfo
 from ..local_predictor import LocalPredictable
 
 
+class DecisionTreeRegressor(Estimator, HasLazyPrintModelInfo):
+    CLS_NAME = 'com.alibaba.alink.pipeline.regression.DecisionTreeRegressor'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(DecisionTreeRegressor, self).__init__(*args, **kwargs)
+        pass
+
+    def setFeatureCols(self, val):
+        return self._add_param('featureCols', val)
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setCategoricalCols(self, val):
+        return self._add_param('categoricalCols', val)
+
+    def setCreateTreeMode(self, val):
+        return self._add_param('createTreeMode', val)
+
+    def setMaxBins(self, val):
+        return self._add_param('maxBins', val)
+
+    def setMaxDepth(self, val):
+        return self._add_param('maxDepth', val)
+
+    def setMaxLeaves(self, val):
+        return self._add_param('maxLeaves', val)
+
+    def setMaxMemoryInMB(self, val):
+        return self._add_param('maxMemoryInMB', val)
+
+    def setMinInfoGain(self, val):
+        return self._add_param('minInfoGain', val)
+
+    def setMinSampleRatioPerChild(self, val):
+        return self._add_param('minSampleRatioPerChild', val)
+
+    def setMinSamplesPerLeaf(self, val):
+        return self._add_param('minSamplesPerLeaf', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+
 class DocCountVectorizer(Estimator):
     CLS_NAME = 'com.alibaba.alink.pipeline.nlp.DocCountVectorizer'
     OP_TYPE = 'FUNCTION'
@@ -33,6 +98,15 @@ class DocCountVectorizer(Estimator):
     def setMinTF(self, val):
         return self._add_param('minTF', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -59,6 +133,15 @@ class DocCountVectorizerModel(Model, LocalPredictable):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -236,6 +319,41 @@ class EqualWidthDiscretizerModel(Model, LocalPredictable):
         return self._add_param('reservedCols', val)
 
 
+class ExtractMfccFeature(Transformer, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.audio.ExtractMfccFeature'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ExtractMfccFeature, self).__init__(*args, **kwargs)
+        pass
+
+    def setSampleRate(self, val):
+        return self._add_param('sampleRate', val)
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setHopTime(self, val):
+        return self._add_param('hopTime', val)
+
+    def setNumMfcc(self, val):
+        return self._add_param('numMfcc', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setWindowTime(self, val):
+        return self._add_param('windowTime', val)
+
+
 class FeatureHasher(Transformer, LocalPredictable):
     CLS_NAME = 'com.alibaba.alink.pipeline.feature.FeatureHasher'
     OP_TYPE = 'FUNCTION'
@@ -316,6 +434,9 @@ class FmClassifier(Estimator, HasLazyPrintModelInfo, HasLazyPrintTrainInfo):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setBatchSize(self, val):
+        return self._add_param('batchSize', val)
+
     def setEpsilon(self, val):
         return self._add_param('epsilon', val)
 
@@ -337,9 +458,6 @@ class FmClassifier(Estimator, HasLazyPrintModelInfo, HasLazyPrintTrainInfo):
     def setLearnRate(self, val):
         return self._add_param('learnRate', val)
 
-    def setMinibatchSize(self, val):
-        return self._add_param('minibatchSize', val)
-
     def setModelStreamFilePath(self, val):
         return self._add_param('modelStreamFilePath', val)
 
@@ -402,15 +520,6 @@ class FmItemsPerUserRecommender(Model, LocalPredictable):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -437,15 +546,6 @@ class FmRateRecommender(Model, LocalPredictable):
     def setUserCol(self, val):
         return self._add_param('userCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -504,6 +604,9 @@ class FmRegressor(Estimator, HasLazyPrintModelInfo, HasLazyPrintTrainInfo):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setBatchSize(self, val):
+        return self._add_param('batchSize', val)
+
     def setEpsilon(self, val):
         return self._add_param('epsilon', val)
 
@@ -525,9 +628,6 @@ class FmRegressor(Estimator, HasLazyPrintModelInfo, HasLazyPrintTrainInfo):
     def setLearnRate(self, val):
         return self._add_param('learnRate', val)
 
-    def setMinibatchSize(self, val):
-        return self._add_param('minibatchSize', val)
-
     def setModelStreamFilePath(self, val):
         return self._add_param('modelStreamFilePath', val)
 
@@ -590,15 +690,6 @@ class FmUsersPerItemRecommender(Model, LocalPredictable):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -745,8 +836,8 @@ class GbdtClassifier(Estimator, HasLazyPrintModelInfo):
     def setCategoricalCols(self, val):
         return self._add_param('categoricalCols', val)
 
-    def setCriteriaType(self, val):
-        return self._add_param('criteriaType', val)
+    def setCriteria(self, val):
+        return self._add_param('criteria', val)
 
     def setFeatureImportanceType(self, val):
         return self._add_param('featureImportanceType', val)
@@ -840,8 +931,8 @@ class GbdtEncoder(Estimator):
     def setCategoricalCols(self, val):
         return self._add_param('categoricalCols', val)
 
-    def setCriteriaType(self, val):
-        return self._add_param('criteriaType', val)
+    def setCriteria(self, val):
+        return self._add_param('criteria', val)
 
     def setFeatureImportanceType(self, val):
         return self._add_param('featureImportanceType', val)
@@ -961,8 +1052,8 @@ class GbdtRegEncoder(Estimator):
     def setCategoricalCols(self, val):
         return self._add_param('categoricalCols', val)
 
-    def setCriteriaType(self, val):
-        return self._add_param('criteriaType', val)
+    def setCriteria(self, val):
+        return self._add_param('criteria', val)
 
     def setFeatureImportanceType(self, val):
         return self._add_param('featureImportanceType', val)
@@ -1114,8 +1205,8 @@ class GbdtRegressor(Estimator, HasLazyPrintModelInfo):
     def setCategoricalCols(self, val):
         return self._add_param('categoricalCols', val)
 
-    def setCriteriaType(self, val):
-        return self._add_param('criteriaType', val)
+    def setCriteria(self, val):
+        return self._add_param('criteria', val)
 
     def setFeatureImportanceType(self, val):
         return self._add_param('featureImportanceType', val)
@@ -1772,6 +1863,15 @@ class IsotonicRegressionModel(Model, LocalPredictable):
         super(IsotonicRegressionModel, self).__init__(*args, **kwargs)
         pass
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
 
 class ItemCfItemsPerUserRecommender(Model, LocalPredictable):
     CLS_NAME = 'com.alibaba.alink.pipeline.recommendation.ItemCfItemsPerUserRecommender'
@@ -1798,15 +1898,6 @@ class ItemCfItemsPerUserRecommender(Model, LocalPredictable):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1833,15 +1924,6 @@ class ItemCfRateRecommender(Model, LocalPredictable):
     def setUserCol(self, val):
         return self._add_param('userCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1871,15 +1953,6 @@ class ItemCfSimilarItemsRecommender(Model, LocalPredictable):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1912,15 +1985,6 @@ class ItemCfUsersPerItemRecommender(Model, LocalPredictable):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -2011,61 +2075,3 @@ class JsonToKv(Transformer, LocalPredictable):
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-
-class JsonToVector(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.JsonToVector'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(JsonToVector, self).__init__(*args, **kwargs)
-        pass
-
-    def setJsonCol(self, val):
-        return self._add_param('jsonCol', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorSize(self, val):
-        return self._add_param('vectorSize', val)
-
-
-class JsonValue(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.JsonValue'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(JsonValue, self).__init__(*args, **kwargs)
-        pass
-
-    def setJsonPath(self, val):
-        return self._add_param('jsonPath', val)
-
-    def setOutputCols(self, val):
-        return self._add_param('outputCols', val)
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputColTypes(self, val):
-        return self._add_param('outputColTypes', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setSkipFailed(self, val):
-        return self._add_param('skipFailed', val)
-
