@@ -4,32 +4,6 @@
 from ..base import StreamOperator, BaseSinkStreamOp, BaseModelStreamOp
 
 
-class EvalBinaryClassStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.evaluation.EvalBinaryClassStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(EvalBinaryClassStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setPositiveLabelValueString(self, val):
-        return self._add_param('positiveLabelValueString', val)
-
-    def setTimeInterval(self, val):
-        return self._add_param('timeInterval', val)
-
-
 class EvalMultiClassStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.evaluation.EvalMultiClassStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -95,11 +69,11 @@ class ExtractMfccFeatureStreamOp(StreamOperator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
-    def setHopSecond(self, val):
-        return self._add_param('hopSecond', val)
+    def setHopTime(self, val):
+        return self._add_param('hopTime', val)
 
-    def setNMfcc(self, val):
-        return self._add_param('nMfcc', val)
+    def setNumMfcc(self, val):
+        return self._add_param('numMfcc', val)
 
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
@@ -110,8 +84,8 @@ class ExtractMfccFeatureStreamOp(StreamOperator):
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-    def setWindowSecond(self, val):
-        return self._add_param('windowSecond', val)
+    def setWindowTime(self, val):
+        return self._add_param('windowTime', val)
 
 
 class FeatureHasherStreamOp(StreamOperator):
@@ -263,15 +237,6 @@ class FmItemsPerUserRecommStreamOp(BaseModelStreamOp):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -339,15 +304,6 @@ class FmUsersPerItemRecommStreamOp(BaseModelStreamOp):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -394,15 +350,6 @@ class FtrlPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -833,6 +780,44 @@ class IndexToStringPredictStreamOp(BaseModelStreamOp):
         return self._add_param('reservedCols', val)
 
 
+class InternalCsvSourceStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.common.io.csv.InternalCsvSourceStreamOp'
+    OP_TYPE = 'SOURCE'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(InternalCsvSourceStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setFilePath(self, val):
+        return self._add_param('filePath', val)
+
+    def setSchemaStr(self, val):
+        return self._add_param('schemaStr', val)
+
+    def setFieldDelimiter(self, val):
+        return self._add_param('fieldDelimiter', val)
+
+    def setHandleInvalidMethod(self, val):
+        return self._add_param('handleInvalidMethod', val)
+
+    def setIgnoreFirstLine(self, val):
+        return self._add_param('ignoreFirstLine', val)
+
+    def setLenient(self, val):
+        return self._add_param('lenient', val)
+
+    def setQuoteChar(self, val):
+        return self._add_param('quoteChar', val)
+
+    def setRowDelimiter(self, val):
+        return self._add_param('rowDelimiter', val)
+
+    def setSkipBlankLine(self, val):
+        return self._add_param('skipBlankLine', val)
+
+
 class IsolationForestsPredictStreamOp(BaseModelStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.outlier.IsolationForestsPredictStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -916,15 +901,6 @@ class ItemCfItemsPerUserRecommStreamOp(BaseModelStreamOp):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -951,15 +927,6 @@ class ItemCfRateRecommStreamOp(BaseModelStreamOp):
     def setUserCol(self, val):
         return self._add_param('userCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -989,15 +956,6 @@ class ItemCfSimilarItemsRecommStreamOp(BaseModelStreamOp):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1030,15 +988,6 @@ class ItemCfUsersPerItemRecommStreamOp(BaseModelStreamOp):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1320,6 +1269,15 @@ class KerasSequentialClassifierPredictStreamOp(BaseModelStreamOp):
     def setInferBatchSize(self, val):
         return self._add_param('inferBatchSize', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setPredictionDetailCol(self, val):
         return self._add_param('predictionDetailCol', val)
 
@@ -1343,6 +1301,15 @@ class KerasSequentialRegressorPredictStreamOp(BaseModelStreamOp):
     def setInferBatchSize(self, val):
         return self._add_param('inferBatchSize', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
@@ -1379,6 +1346,44 @@ class KeywordsExtractionStreamOp(StreamOperator):
         return self._add_param('windowSize', val)
 
 
+class KnnPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.classification.KnnPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(KnnPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setK(self, val):
+        return self._add_param('k', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+
 class KvToColumnsStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.KvToColumnsStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -1535,32 +1540,3 @@ class KvToVectorStreamOp(StreamOperator):
     def setVectorSize(self, val):
         return self._add_param('vectorSize', val)
 
-
-class LSTNetPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.timeseries.LSTNetPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LSTNetPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setValueCol(self, val):
-        return self._add_param('valueCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setPredictNum(self, val):
-        return self._add_param('predictNum', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
