@@ -4,6 +4,154 @@
 from ..base import StreamOperator, BaseSinkStreamOp, BaseModelStreamOp
 
 
+class LSTNetPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.timeseries.LSTNetPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(LSTNetPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setValueCol(self, val):
+        return self._add_param('valueCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictNum(self, val):
+        return self._add_param('predictNum', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class LassoRegPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.regression.LassoRegPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(LassoRegPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+
+class LdaPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.clustering.LdaPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(LdaPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class LibSvmSinkStreamOp(BaseSinkStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.sink.LibSvmSinkStreamOp'
+    OP_TYPE = 'SINK'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(LibSvmSinkStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setFilePath(self, val):
+        return self._add_param('filePath', val)
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+    def setOverwriteSink(self, val):
+        return self._add_param('overwriteSink', val)
+
+    def setStartIndex(self, val):
+        return self._add_param('startIndex', val)
+
+
+class LibSvmSourceStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.source.LibSvmSourceStreamOp'
+    OP_TYPE = 'SOURCE'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(LibSvmSourceStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setFilePath(self, val):
+        return self._add_param('filePath', val)
+
+    def setStartIndex(self, val):
+        return self._add_param('startIndex', val)
+
+
 class LinearRegPredictStreamOp(BaseModelStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.regression.LinearRegPredictStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -650,6 +798,15 @@ class PipelinePredictStreamOp(StreamOperator):
         super(PipelinePredictStreamOp, self).__init__(*args, **kwargs)
         pass
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -687,6 +844,15 @@ class ProphetPredictStreamOp(BaseModelStreamOp):
     def setValueCol(self, val):
         return self._add_param('valueCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -696,6 +862,9 @@ class ProphetPredictStreamOp(BaseModelStreamOp):
     def setPredictionDetailCol(self, val):
         return self._add_param('predictionDetailCol', val)
 
+    def setPythonEnv(self, val):
+        return self._add_param('pythonEnv', val)
+
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
@@ -725,6 +894,9 @@ class ProphetStreamOp(StreamOperator):
     def setPredictionDetailCol(self, val):
         return self._add_param('predictionDetailCol', val)
 
+    def setPythonEnv(self, val):
+        return self._add_param('pythonEnv', val)
+
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
@@ -978,18 +1150,18 @@ class ReadAudioToTensorStreamOp(StreamOperator):
     def setSampleRate(self, val):
         return self._add_param('sampleRate', val)
 
-    def setDurationTime(self, val):
-        return self._add_param('durationTime', val)
+    def setDuration(self, val):
+        return self._add_param('duration', val)
 
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
+    def setOffset(self, val):
+        return self._add_param('offset', val)
+
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-    def setStartTime(self, val):
-        return self._add_param('startTime', val)
-
 
 class ReadImageToTensorStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.image.ReadImageToTensorStreamOp'
@@ -1020,6 +1192,70 @@ class ReadImageToTensorStreamOp(StreamOperator):
         return self._add_param('reservedCols', val)
 
 
+class RecommendationRankingStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.recommendation.RecommendationRankingStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RecommendationRankingStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setMTableCol(self, val):
+        return self._add_param('mTableCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setRankingCol(self, val):
+        return self._add_param('rankingCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setTopN(self, val):
+        return self._add_param('topN', val)
+
+
+class RedisSinkStreamOp(BaseSinkStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.sink.RedisSinkStreamOp'
+    OP_TYPE = 'SINK'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RedisSinkStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPluginVersion(self, val):
+        return self._add_param('pluginVersion', val)
+
+    def setRedisIP(self, val):
+        return self._add_param('redisIP', val)
+
+    def setKeyCols(self, val):
+        return self._add_param('keyCols', val)
+
+    def setRedisPassword(self, val):
+        return self._add_param('redisPassword', val)
+
+    def setRedisPort(self, val):
+        return self._add_param('redisPort', val)
+
+    def setValueCols(self, val):
+        return self._add_param('valueCols', val)
+
+
 class RegexTokenizerStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.nlp.RegexTokenizerStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -1235,176 +1471,3 @@ class SocketSinkStreamOp(BaseSinkStreamOp):
     def setPort(self, val):
         return self._add_param('port', val)
 
-
-class SoftmaxPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.classification.SoftmaxPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(SoftmaxPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-
-class SplitStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.SplitStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(SplitStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setFraction(self, val):
-        return self._add_param('fraction', val)
-
-    def setRandomSeed(self, val):
-        return self._add_param('randomSeed', val)
-
-
-class SqlCmdStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.sql.SqlCmdStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(SqlCmdStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setAlias(self, val):
-        return self._add_param('alias', val)
-
-    def setCommand(self, val):
-        return self._add_param('command', val)
-
-
-class StandardScalerPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.StandardScalerPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(StandardScalerPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCols(self, val):
-        return self._add_param('outputCols', val)
-
-
-class StopWordsRemoverStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.nlp.StopWordsRemoverStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(StopWordsRemoverStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setCaseSensitive(self, val):
-        return self._add_param('caseSensitive', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setStopWords(self, val):
-        return self._add_param('stopWords', val)
-
-
-class StratifiedSampleStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.StratifiedSampleStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(StratifiedSampleStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setStrataCol(self, val):
-        return self._add_param('strataCol', val)
-
-    def setStrataRatios(self, val):
-        return self._add_param('strataRatios', val)
-
-    def setStrataRatio(self, val):
-        return self._add_param('strataRatio', val)
-
-
-class StreamingKMeansStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.clustering.StreamingKMeansStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(StreamingKMeansStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setHalfLife(self, val):
-        return self._add_param('halfLife', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setTimeInterval(self, val):
-        return self._add_param('timeInterval', val)
-
-    def setPredictionClusterCol(self, val):
-        return self._add_param('predictionClusterCol', val)
-
-    def setPredictionDistanceCol(self, val):
-        return self._add_param('predictionDistanceCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
